@@ -152,6 +152,9 @@ noEffect = phantom (pure ())
 ( .# ) pbc _ = unsafeCoerce pbc
 #endif
 
+infixr 9 #.
+infixl 8 .#
+
 ------------------------------------------------------------------------------
 -- classes
 ------------------------------------------------------------------------------
